# C3PO: CHEBI Classification Programs Ontology

Learning classification programs to categorize SMILES strings into [CHEBI](https://www.ebi.ac.uk/chebi/) classes.

![logo](docs/assets/c3p-small.png)

See [Slides](https://docs.google.com/presentation/d/1VJvRptWu6FhTTmZGM4X3ymbxn9JwYPWDUp9djfMfDao/edit#slide=id.p)

## Usage

```bash
pip install c3p
c3p -x "CC1=CC=C(C=C1)C1=C(C#N)C2=NC3=CC=CC=C3N2C(N)=C1C#N"
```

## Learning Programs

All code in Notebook

Example [generated programs](c3p/programs/)
